class WebTechnologies:
    def __init__(self, soup):
        dict = self.scrape_dict(soup)
        
    def _scrape_dict(self, soup):
        dict = {
                "gerald": "14",
                "neinold": "12"
                }
